# pybalu

![Build and upload to PyPI](https://github.com/mbucchi/pybalu/workflows/Build%20and%20upload%20to%20PyPI/badge.svg)

Python implementation for Balu, a computer vision, pattern recognition and image processing library. Originally implemented in matlab by Domingo Mery.

## Installing pybalu

Python 3.6 or higher is required to use this package. In order to install pybalu, simply run

```bash
$ pip install pybalu
```

## Development and contributing

If you would like to contribute:

- Fork the repo
- Create a new branch called `feature/<feature-desc>` or `fix/<fix-desc>` depending on the nature of your contribution
- Perform a pull request and wait for your contribution to be accepted or rejected

Possible and useful contributions:

- Tests
- More feature extraction, analysis and transformation funcitons
- Fixes
- Documentation
- Examples

## Documentation

_TODO_
